Documentation
¶
Overview ¶
Package v1alpha1 is the v1alpha1 version of the API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: batch.GroupName, Version: "v1alpha1"}
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Types ¶
type Job ¶
type Job struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec JobSpec `json:"spec,omitempty"`
Status JobStatus `json:"status,omitempty"`
}
Job is the Schema for the jobs API +k8s:openapi-gen=true
func (*Job) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Job.
func (*Job) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Job) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type JobList ¶
type JobList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Job `json:"items"`
}
JobList contains a list of Job
func (*JobList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobList.
func (*JobList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*JobList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type JobSpec ¶
type JobSpec struct {
// INSERT ADDITIONAL SPEC FIELDS -- desired state of cluster
MaxRetry int32 `json:"maxRetry"`
MinAvailable int32 `json:"minAvailable"`
MinSuccess int32 `json:"minSuccess"`
PriorityClassName string `json:"priorityClassName"`
Queue string `json:"queue"`
RunningEstimate string `json:"runningEstimate"`
SchedulerName string `json:"schedulerName"`
TtlSecondsAfterFinished int32 `json:"ttlSecondsAfterFinished"`
}
JobSpec defines the desired state of Job
func (*JobSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobSpec.
func (*JobSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type JobStatus ¶
type JobStatus struct {
// INSERT ADDITIONAL STATUS FIELDS -- observed state of cluster
Failed int32 `json:"failed"`
MinAvailable int32 `json:"minAvailable"`
Pending int32 `json:"pending"`
RetryCount int32 `json:"retryCount"`
Running int32 `json:"running"`
RunningDuration string `json:"runningDuration"`
Succeeded int32 `json:"succeeded"`
Terminating int32 `json:"terminating"`
Unknown int32 `json:"unknown"`
Version int32 `json:"version"`
}
JobStatus defines the observed state of Job. It should always be reconstructable from the state of the cluster and/or outside world.
func (*JobStatus) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobStatus.
func (*JobStatus) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.