Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BatchV1alpha1Client ¶
type BatchV1alpha1Client struct {
// contains filtered or unexported fields
}
BatchV1alpha1Client is used to interact with features provided by the batch.volcano.sh group.
func New ¶
func New(c rest.Interface) *BatchV1alpha1Client
New creates a new BatchV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*BatchV1alpha1Client, error)
NewForConfig creates a new BatchV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *BatchV1alpha1Client
NewForConfigOrDie creates a new BatchV1alpha1Client for the given config and panics if there is an error in the config.
func (*BatchV1alpha1Client) Jobs ¶
func (c *BatchV1alpha1Client) Jobs(namespace string) JobInterface
func (*BatchV1alpha1Client) RESTClient ¶
func (c *BatchV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type BatchV1alpha1Interface ¶
type BatchV1alpha1Interface interface {
RESTClient() rest.Interface
JobsGetter
}
type JobExpansion ¶
type JobExpansion interface{}
type JobInterface ¶
type JobInterface interface {
Create(ctx context.Context, job *v1alpha1.Job, opts v1.CreateOptions) (*v1alpha1.Job, error)
Update(ctx context.Context, job *v1alpha1.Job, opts v1.UpdateOptions) (*v1alpha1.Job, error)
UpdateStatus(ctx context.Context, job *v1alpha1.Job, opts v1.UpdateOptions) (*v1alpha1.Job, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Job, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.JobList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Job, err error)
JobExpansion
}
JobInterface has methods to work with Job resources.
type JobsGetter ¶
type JobsGetter interface {
Jobs(namespace string) JobInterface
}
JobsGetter has a method to return a JobInterface. A group's client should implement this interface.